% NELS 42 LaTeX class

% Based on the NELS 2003 style sheet instructions.  Written by Uli 
% Sauerland.  A few parts were taken from Alexis Dimitriadis's salt.cls. 
% Modified by Jan Anderssen for NELS 36 in 2006.
% Modified some more by Nick LaCara in 2011 to fix errors discovered
%  whilst editing NELS 41 and to make things a little more presentable.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% REQUIREMENTS:
%
% TO USE THIS CLASS YOU MUST HAVE THE MEMOIR CLASS, AND THE NATBIB
% PACKAGE INSTALLED. BOTH ARE AVAILABLE FROM CTAN (memoir.cls AND
% natbib.sty).
% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% READ THESE INSTRUCTIONS BEFORE YOU USE THIS CLASS!
%
% USAGE:
% 
% Use this file INSTEAD of the `memoir' class:
% \documentclass{nels51}
%
% This class definition does not provide an example environment.
% It does call natbib.
%
% TITLE BLOCK DIRECTIONS:
%
% To format your title and name, use the standard commands \title{...},
% \author{...}, the non-standard \affiliation{...}, and \maketitle.
%
% Use the standard command \thanks{...} if you want to provide an
% acknowledgment footnote in the title. 
%
% Most NELS papers use 14pt leading, which seems to be the default of 
% Microsoft Word with Times Roman.  To my eyes, Latex's 14.5pt leading is more 
% readable, so I left this unchanged.
%
% PAGE HEADERS: Author's name(s) and the title are automatically put
% in the headers.  However, if the authors' names or the title are
% longer than 50 characters, you should enter a shorter version below,
% and uncomment the line.
% 
%\markboth{Lauren Clemens}{The prosody of niuean pseudo noun incorporation}
%
% PAGE NUMBERS AND REFERENCE: (Updated by Nick LaCara)
%
% When submitting your paper for publication, it should not have any
% page numbers. The NELS editors will will add those once the volume
% has been compiled. However, for electronic distribution or editing
% purposes, it may be useful for you to have page numbers. 
%
% If you want or need page numbers, call \pagenumbers in the preamble.
% This will do two things. First, it will print page numbers on each
% page. It will also print a small reference in the bottom corner of 
% the first page.
% 
% To set the page numbers to match the published version, include the
% following command in the preamble:
%
% \setcounter{page}{xxx}
%
%  For the submitted version, please make sure that both the reference 
%  and the page numbers are not in your document!
%
%
% A NOTE ON nels51.CLS AND QTREE
%
% This class uses memoir. Memoir and qtree in combination are known 
% to run out of skip registers. If you have a reasonably recent 
% etex based distribution (try latex -v and see whether it says
% pdfetex or something similar), try loading the package etex 
% before(!) loading qtree. This is likely to fix your problems.
%
%  (End of the usage directions)

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{nels51}[2021/01/18 NELS 51 Proceedings Style]

\DeclareOption*{\PassOptionsToClass{\CurrentOption}{memoir}}

\newcommand{\@sizeoption@err}{\ClassError{nels51}
  {Cannot use size option \CurrentOption} 
  {The NELS 51 style requires (and automatically loads) 12pt text}}

\DeclareOption{10pt}{\@sizeoption@err}
\DeclareOption{11pt}{\@sizeoption@err}

\ProcessOptions 
\LoadClass[12pt,twoside,letterpaper]{memoir}

% 1. FONT 

\RequirePackage{textcomp}
\RequirePackage{mathptmx}
%\RequirePackage[mtbold]{mathtime}

\RequirePackage[scaled=0.92]{helvet}
 
\def\familydefault{ptm}

% 2. PAGE LAYOUT

\settrimmedsize{11in}{8.5in}{*}
\setlrmarginsandblock{1.5in}{1in}{*}
\setulmarginsandblock{1.12in}{1.1in}{*} 
\setheadfoot{\onelineskip}{\onelineskip}
\setheaderspaces{*}{0.144in}{*}
\checkandfixthelayout

% 3. SECTIONS

% I allow a little flexibility with before and after section spacing,
% to achieve flush page bottoms.  Uncommenting the two lines below
% achieve exactly one lineskip (=14.5pt).

\setsecnumdepth{subsubsection}
\def\thesection{\arabic{section}}
\renewcommand{\chapter}{\ClassError{nels51}
  {Cannot use the chapter-command} 
  {The NELS style allows only section headings}}
\skip0 = 0pt plus 2pt minus 2pt
\advance\skip0 by \onelineskip
\setbeforesecskip{-\skip0}
% \setbeforesecskip{-\onelineskip} % uncomment for strict adherence
\setbeforesubsecskip{-\skip0}
% \setbeforesubsecskip{-\onelineskip} % uncomment for strict adherence
\setsecindent{0in}

\setsubsecindent{0in}
\setsecheadstyle{\normalfont\bfseries\raggedright}
\setsubsecheadstyle{\normalfont\bfseries\raggedright}
\setaftersecskip{\onelineskip}
\setaftersubsecskip{\onelineskip}
\setsecnumformat{\hbox to .5in {\csname the#1\endcsname.\hfill}}
\setsubsechook{\setsecnumformat{\hbox to .5in {\csname the##1\endcsname\hfill}}}
\setsechook{\setsecnumformat{\hbox to .5in {\csname the##1\endcsname.\hfill}}}

\setsubsubsecindent{0in}
\setsubsubsecheadstyle{\normalfont\bfseries\raggedright}
\setaftersubsubsecskip{\onelineskip}
\setsubsubsechook{\setsecnumformat{\hbox to .5in{\csname the##1\endcsname\hfill}}}

% 4. PAGE STYLE

% \copypagestyle{nels51}{myheadings}
% \makeoddhead{nels51}{}{\textit{\rightmark}}{\thepage}
% \makeevenhead{nels51}{\thepage}{\leftmark}{}
% \pagestyle{nels51}

% \def\nopagenumbers{\makeoddhead{nels36}{}{\textit{\rightmark}}{}
% \makeevenhead{nels36}{}{\leftmark}{}
% \makeoddfoot{title}{}{}{}}

\copypagestyle{nels51}{myheadings}
\makeoddhead{nels51}{}{\textit{\rightmark}}{}
\makeevenhead{nels51}{}{\leftmark}{}
\pagestyle{nels51}
\makeoddfoot{empty}{}{}{}

\def\pagenumbers{
\makeoddhead{nels51}{}{\textit{\rightmark}}{\thepage}
\makeevenhead{nels51}{\thepage}{\leftmark}{}
\pagestyle{nels51}
\makeoddfoot{title}{\flushleft\tiny{\@reference}}{}{}
\makeevenfoot{title}{\flushleft\tiny{\@reference}}{}{}}

% 5. HEADER TEXT

%\AtBeginDocument{{\def\thanks#1{}\markboth{\@author}{\@title}}\reference
%{\copyright\ 2015 by \@author\\
%Thuy Bui and Deniz Odzyildiz (eds.), NELS 45: 
%\thepage--\arabic{lastpage}}}

% 6. TITLE

\droptitle=.42in %% 7\onelineskip seven empty lines before the title
\pretitle{\centering\normalsize\normalfont\bfseries}
\posttitle{\par\vspace*{.38in}}% two empty lines after title 
\preauthor{\centering\normalsize\normalfont}
\postauthor{\par\vspace*{.17in}}% one empty line after authors
\predate{\centering\normalsize\normalfont}
\postdate{\par\vspace*{.5in}}% four empty lines after affiliation

% the following suppresses paragraph indentation and pre-section 
% vertical space after the title
\def\maketitlehookd{\@afterindenttrue\@afterheading}
\def\affiliation#1{\gdef\@date{#1}}

\copypagestyle{title}{empty}

\def\reference#1{\gdef\@reference{#1}}

% 7. TEXT 

\setlength{\parindent}{.25in}
\setlength{\parskip}{0pt}%0pt plus 1pt

% Footnote Formatting (Updated by NL,SK)

\setlength{\footmarkwidth}{0.25in}
\setlength{\footmarksep}{-0.25in}
\setlength{\footparindent}{0.25in}

% Acknowledgment footnote formatting (NL,SK)
\setlength{\thanksmarkwidth}{\footmarkwidth}
\setlength{\thanksmarksep}{\footmarksep}

% preventing widows
\widowpenalty=10000
\frenchspacing

%% This is the orginal footnote command from NELS36.CLS, but it 
%% doesn't cover everything that it should, like paragraph indents 
%% in footnotes or the thanks footnote. -NL
%
% \renewcommand{\makefootmarkhook}{\hspace{0.5in}}

%%%% Added from UMOP.cls
% 8. Resetting Tables and Figures: since we're using memoir class
% without page numbers, we need to reset the tablecounter as follows:
\renewcommand{\thetable}{\arabic{table}}
\renewcommand{\thefigure}{\arabic{figure}}


% 8. EXAMPLES
% 
% Use your own example macros: Each example style must have its margins
% adjusted in a different way.  
%

% 9. BIBLIOGRAPHY

% The following relies on the natbib-package.  You still need to 
% declare a bibliography style, e.g. \bibliographystyle{linquiry2.bst}.

\usepackage[sectionbib]{natbib}
\renewcommand\betweenauthors{and}
\bibhang=.25in
\renewenvironment{thebibliography}[1]{%
\setbeforesecskip{2\onelineskip}
\setsecheadstyle{\normalfont\bfseries\centering}
\section*{References}%
\parindent \z@\bibpreamble\bibfont\list
   {\@biblabel{\arabic{NAT@ctr}}}{\@bibsetup{#1}%
    \setcounter{NAT@ctr}{0}}%
    \ifNAT@openbib
      \renewcommand\newblock{\par}
    \else
      \renewcommand\newblock{\hskip .11em \@plus.33em \@minus.07em}%
    \fi
    \sloppy\clubpenalty4000\widowpenalty4000
    \sfcode`\.=1000\relax
    \let\citeN\cite\let\shortcite\cite
    \let\citeasnoun\cite
    \tightlist%no space between the bibliography items
 }{\def\@noitemerr{%
  \PackageWarning{natbib}
     {Empty `thebibliography' environment}}%
  \endlist\vskip-\lastskip}
\bibpunct{(}{)}{,}{a}{}{,}
\setcitestyle{notesep={:}}